function [FastSMTArray, FastSMTWeights] = SMT2FastSMT(SMTArray, S)
%
% Converts an SMT Array into a fast SMT Array.
% Each fast SMT butterfly can be computed with 2 multiplies.
%
% Inputs:
%   SMTArray[NumRotations,3] - array of SMT rotations
%   S[N] - array of initial weights for an N dimensional SMT
%
% Outputs:
%   FastSMTArray[NumRotations,4] - array of fast SMT rotations
%   FastSMTWeights[N] - array of final weights for an N dimensional SMT
%
% So the result has the property that
%          diag(FastSMTWeights)*FastSMT = SMT*diag(S)
% 
% Typically, S=ones(N,1) or s = diag(R).^(-1/2) for more general cases


[NumRotations, junk] = size(SMTArray);

FastSMTArray=zeros(NumRotations, 4);

for k=1:NumRotations
     i=SMTArray(k,1);
     j=SMTArray(k,2);
     theta=SMTArray(k,3); 
                                                                                  
     d1=S(i)*cos(theta);
     d2=S(j)*cos(theta);
    
     a=-S(i)/S(j)*tan(theta);
     b=S(j)/S(i)*tan(theta); 

     S(i)=d1;
     S(j)=d2;
       
     FastSMTArray(k,1)=i;
     FastSMTArray(k,2)=j;
     FastSMTArray(k,3)=a;
     FastSMTArray(k,4)=b;
end

FastSMTWeights = S;
